;----------------------------------------------------------------------------------
;	FILE:			PwrLibTestbench-DPL-ISR.asm
;
;	Description:	{ProjectName}-DPL-ISR.asm contains the ISR for the system
;					It also contains the initailization routine for all the macros 
;					being used in the system both for CLA and C28x macros
;   
;   Revision/ Version: See {ProjectName}-Main.c
;----------------------------------------------------------------------------------

		;Gives peripheral addresses visibility in assembly
	    .cdecls   C,LIST,"PeripheralHeaderIncludes.h"

		;include C header file - sets INCR_BUILD etc.(used in conditional builds)
		.cdecls C,NOLIST, "SolarHv_DCAC-Settings.h"

		;Include files for the Power Library Maco's being used by the system 
		.include "SolarHv_DCAC-DLOG_4ch.asm"
		.include "SolarHv_DCAC-ADCDRV_5CH.asm"
		.include "SolarHv_DCAC-PWMDRV.asm"
		.include "CNTL_2P2Z.asm"
		.include "SolarHv_DCAC-INV_ICMD.asm"
		.include "SolarHv_DCAC-GEN_SIN_COS.asm"
		.include "SolarHv_DCAC-CNTL_2P2Z.asm"
		
;=============================================================================
; Digital Power library - Initailization Routine 
;=============================================================================

		; label to DP initialisation function
		.def _DPL_Init	
		; label to DP ISR Run function
		.def _DPL_ISR
		; lable to zero the buffer of the control loop
		.def _DPL_Zero_Buff
		
		; dummy variable for pointer initialisation
ZeroNet	 .usect "ZeroNet_Section",2,1,1	; output terminal 1
VloopCtr .usect "ISRVariables",2,1,1

		.ref   _dwSinIndexPointer
		.ref   _wCycleFlag
		.ref   _wSinAmp
		.ref   _dwInv_Voltage_1,_dwBus_Voltage_Fbk,_dwBus_Voltage_Loop_Out,_dwBus_Voltage_Loop_Out_1
		.ref   _wSinTab
		.ref   _dwInv_Voltage,_dwInv_Current_1,_dwInv_Current_2
		.ref   _dwInv_Curr_LoopOut,_dwDuty_Cal_Out
		.ref   _dwDuty_Cal_Max,_dwDuty_Cal_Min
		.ref   _dwRef_Sin_Cal_Ratio,_dwRef_Sin_Out,_dwPhase_Error_Out,_dwPllCon_Out
		.ref   _dwPhase_Err_Max,_dwPhase_Err_Min
		.ref   _dwPll_Cos_out,_dwPll_Sin_Out
		.ref   _dwDeltaTemp
		.ref   _dwInv_Frequency,_dwSine_Ref
		.ref   _dwPll_Trace_Freq,_dwPll_Trace_Freq_Ratio
		.ref   _dwPhase_Err_Offset,_dwTestTemp
		.ref   _dwInvVoltSumTemp,_dwInvCurrSumTemp,_dwDcBusSumTemp,_dwActivePowerSumTemp
		.ref   _wSumCntTemp,_dwInvCurrSum,_dwDcBusSum,_dwActivePowerSum,_wSumCnt,_dwInvVoltSum
		.ref   _wCyclePeriodCnt,_wBus_V,_wSinAmp_I
		.ref   _wGridTieEnable,_wVoltageLoopEnable,_dwVoltageLoopOutConst

		.text
_DPL_Init:
		ZAPA
		MOVL	XAR0, #ZeroNet
		MOVL	*XAR0, ACC

		; Initialize all the DP library macro used here 	
		
		ADCDRV_5ch_INIT 1,3,3,7,9			// see one note
		CNTL_2P2Z_INIT 1
		SOLAR_CNTL_2P2Z_INIT 2
		CNTL_2P2Z_INIT 3
		CNTL_2P2Z_INIT 4
		INV_ICMD_INIT 1
		DLOG_4ch_INIT 1
		PWMDRV_FBINV_INIT 1,2
		GEN_SIN_COS_INT 1
		
		LRETR
		
_DPL_Zero_Buff:

		ZAPA
		MOVL	XAR0, #ZeroNet
		MOVL	*XAR0, ACC
		
		SOLAR_CNTL_2P2Z_RESET 1
		SOLAR_CNTL_2P2Z_RESET 2

		
		LRETR
;-----------------------------------------------------------------------------------------

; Digital Power library - Interrupt Service Routine

		.sect "ramfuncs"
_DPL_ISR:
		; full context save - push any unprotected registers onto stack
		PUSH  	AR1H:AR0H
		PUSH  	XAR2
		PUSH  	XAR3
		PUSH  	XAR4
		PUSH  	XAR5
		PUSH  	XAR6
		PUSH  	XAR7
		PUSH  	XT
		SPM   	0          				; set C28 mode
		CLRC  	AMODE       
		CLRC  	PAGE0,OVM 
;		CLRC	INTM					; clear interrupt mask - comment if ISR non-nestable
;---------------------------------------------------
		ZAPA	
		MOVW    DP, #_EPwm3Regs.TBSTS
		MOV     ACC, @_EPwm3Regs.TBSTS
		AND     ACC, #0x0001
		B       _DPL_COUNT_UP,NEQ
		
;-------------Count down----------------------------
		ADCDRV_5ch 1,3,3,7,9							; // see one note
		MOVW     DP,#_dwInv_Voltage
		MOVL     ACC,@_dwInv_Voltage
		MOVW     DP,#_dwInv_Voltage_1
		MOVL     @_dwInv_Voltage_1,ACC
		
		MOVW     DP,#_dwInv_Current_1
		MOVL     ACC,@_dwInv_Current_1
		MOVW     DP,#_dwInv_Current_2
		MOVL     @_dwInv_Current_2,ACC

		;The Sin table look up pointer update for test		
		MOVW	   DP,#(_dwSinIndexPointer)
		MOVL       ACC,@_dwSinIndexPointer
		ADD        ACC,#1
		MOV        @_dwSinIndexPointer,ACC
		MOV  	   DP,#_wCyclePeriodCnt
		SUB        ACC,@_wCyclePeriodCnt
		B          _DPL_ISR_Test_1,LT
		MOV        ACC,#0
		MOVW       DP,#_dwSinIndexPointer
		MOVL       @_dwSinIndexPointer,ACC
		MOVW       DP,#_wCycleFlag
		MOV        @_wCycleFlag,#1
		
		MOVW	   DP,#_dwInvVoltSumTemp
		MOVL       ACC,@_dwInvVoltSumTemp
		MOVW       DP,#_dwInvVoltSum
		MOVL       @_dwInvVoltSum,ACC
		
		MOVW	   DP,#_dwInvCurrSumTemp
		MOVL       ACC,@_dwInvCurrSumTemp
		MOVW       DP,#_dwInvCurrSum
		MOVL       @_dwInvCurrSum,ACC
		
		MOVW	   DP,#_dwDcBusSumTemp
		MOVL       ACC,@_dwDcBusSumTemp
		MOVW       DP,#_dwDcBusSum
		MOVL       @_dwDcBusSum,ACC
		
		MOVW	   DP,#_dwActivePowerSumTemp
		MOVL       ACC,@_dwActivePowerSumTemp
		MOVW       DP,#_dwActivePowerSum
		MOVL       @_dwActivePowerSum,ACC
		
		MOVW	   DP,#_wSumCntTemp
		MOV        ACC,@_wSumCntTemp
		MOVW       DP,#_wSumCnt
		MOV        @_wSumCnt,ACC
		
		ZAPA
		MOVW	   DP,#_wSumCntTemp
		MOV        @_wSumCntTemp,ACC
		MOVW	   DP,#_dwActivePowerSumTemp
		MOVL       @_dwActivePowerSumTemp,ACC
		MOVW	   DP,#_dwDcBusSumTemp
		MOVL       @_dwDcBusSumTemp,ACC
		MOVW       DP,#_dwInvCurrSumTemp	
		MOVL       @_dwInvCurrSumTemp,ACC
		MOVW       DP,#_dwInvVoltSumTemp
		MOVL       @_dwInvVoltSumTemp,ACC	   

_DPL_ISR_Test_1:		
;		MOVW  	DP,#_dwSinIndexPointer
;		MOVL  	ACC,@_dwSinIndexPointer
;		MOVL  @XAR1,ACC
;		MOVL  XAR0,#_wSinTab
;		MOV   T,*+XAR0[AR1]
;		
;		MOVW  DP,#_wSinAmp
;		MPY	  P,T,@_wSinAmp		;0.1
;		MOV   ACC,@P
;		
;		MOVW  DP,#_dwInv_Voltage
;		MOVL  @_dwInv_Voltage,ACC
;		
;		MOVW  DP,#_wSinAmp_I
;		MPY   P,T,@_wSinAmp_I
;		MOV   ACC,@P
;		MOVW  DP,#_dwInv_Current_1
;		MOVL  @_dwInv_Current_1,ACC
;		
;		MOVW  DP,#_wBus_V
;		MOV   ACC,@_wBus_V
;		LSL   ACC,#14
;		MOVW  DP,#_dwBus_Voltage_Fbk
;		MOVL  @_dwBus_Voltage_Fbk,ACC	
;_DPL_ISR_Test_1_end:		
		
		;Line Voltage Square Sum
		MOVW   DP,#_dwInv_Voltage
		MOVL   XT,@_dwInv_Voltage
		QMPYL  ACC,XT,@_dwInv_Voltage
		IMPYL  P,XT,@_dwInv_Voltage
		LSL64  ACC:P,#8  					;Q24*Q24=Q48 -> ACC(Q16)<<8 -> Q24
 		MOVW   DP,#_dwInvVoltSumTemp
 		ADDL   ACC,@_dwInvVoltSumTemp
 		MOVL   @_dwInvVoltSumTemp,ACC
 		
 		;Inv Current Square Sum
 		MOVW   DP,#_dwInv_Current_1
		MOVL   XT,@_dwInv_Current_1
		QMPYL  ACC,XT,@_dwInv_Current_1
		IMPYL  P,XT,@_dwInv_Current_1
		LSL64  ACC:P,#8  					;Q24*Q24=Q48 -> ACC(Q16)<<8 -> Q24
 		MOVW   DP,#_dwInvCurrSumTemp		
 		ADDL   ACC,@_dwInvCurrSumTemp
 		MOVL   @_dwInvCurrSumTemp,ACC
 		
 		;Dc Bus Sum
 		MOVW   DP,#_dwBus_Voltage_Fbk
		MOVL   ACC,@_dwBus_Voltage_Fbk
		SFR    ACC,#3
 		MOVW   DP,#_dwDcBusSumTemp
 		ADDL   ACC,@_dwDcBusSumTemp
 		MOVL   @_dwDcBusSumTemp,ACC	
 		
 		;Active Power Sum 
 		MOVW   DP,#_dwInv_Current_1
		MOVL   XT,@_dwInv_Current_1
		MOVW   DP,#_dwInv_Voltage
		QMPYL  ACC,XT,@_dwInv_Voltage
		IMPYL  P,XT,@_dwInv_Voltage
		LSL64  ACC:P,#8  					;Q24*Q24=Q48 -> ACC(Q16)<<8 -> Q24
 		MOVW   DP,#_dwActivePowerSumTemp		
 		ADDL   ACC,@_dwActivePowerSumTemp
 		MOVL   @_dwActivePowerSumTemp,ACC
 		
 		;Increase the sum counter
 		MOVW   DP,#_wSumCntTemp
 		INC    @_wSumCntTemp
 		
 		B       _DPL_COUNT_UP_END,UNC


;--------------Count up-----------------------------
_DPL_COUNT_UP:

_DPL_ISR0:
		;;Calculate the sin use for PLL and current reference
		GEN_SIN_COS 1
		
_DPL_ISR1:
		
		ADCDRV_5ch 1,3,3,7,9      			; // 1,3,5,7,9   See one note.   A lot of issues with this firmware
		
		MOVW     DP,#_dwInv_Voltage_1
		MOVL     ACC,@_dwInv_Voltage_1
		MOVW     DP,#_dwInv_Voltage
		ADDL     ACC,@_dwInv_Voltage
		SFR      ACC,#1
		MOVL     @_dwInv_Voltage,ACC
		
		
		MOVW     DP,#_dwInv_Current_2
		MOVL     ACC,@_dwInv_Current_2
		MOVW     DP,#_dwInv_Current_1
		ADDL     ACC,@_dwInv_Current_1
		SFR      ACC,#1
		MOVL	 @_dwInv_Current_1,ACC

Volt_Loop_Begin:		
		;Execute Vloop every VoltCurrLoopExecRatio times, defined in Settings.h file 	
		MOVW	DP,#(VloopCtr)
		INC		@VloopCtr
		CMP		@VloopCtr,#VoltCurrLoopExecRatio
		B		VL_SKIP,LT
		MOV		@VloopCtr,#0
		
		CNTL_2P2Z 1							;The voltage controller
		MOVW    DP,#_dwBus_Voltage_Loop_Out_1
		MOVL    ACC,@_dwBus_Voltage_Loop_Out_1
		NEG     ACC
		MOVW    DP,#_dwBus_Voltage_Loop_Out
		MOVL    @_dwBus_Voltage_Loop_Out,ACC
		
		MOVW    DP,#_wVoltageLoopEnable
		MOV     AL,@_wVoltageLoopEnable
		CMP     AL,#1
		B		Volt_Loop_Continue,EQ
		MOVW    DP,#_dwVoltageLoopOutConst
		MOVL    ACC,@_dwVoltageLoopOutConst
		MOVW    DP,#_dwBus_Voltage_Loop_Out
		MOVL    @_dwBus_Voltage_Loop_Out,ACC
		
Volt_Loop_Continue
		
		;;;;;;;The Phase error detect for PLL
		;Calculate the reference sin angle
		MOVW    DP,#_dwRef_Sin_Cal_Ratio			
		MOVL    XT,@_dwRef_Sin_Cal_Ratio			;Q20
		MOVW    DP,#_dwInv_Voltage					;Q24		
		IMPYL   P,XT,@_dwInv_Voltage		;P =  Ratio * Inv_Volt[31:0]
		QMPYL   ACC,XT,@_dwInv_Voltage		;ACC = Ratio * Inv_Volt[63:32]
		LSL64   ACC:P,#10					;ACC->Q22
		MOVW    DP,#_dwRef_Sin_Out
		MOVL    @_dwRef_Sin_Out,ACC
		
		;Calculate the phase error
		;Phase_Err = Low Freq of the 2*Ref_Sin*Sin_Out
		;MOVW    DP,#_dwPll_Sin_Out
		;MOVL    XT,@_dwPll_Sin_Out
		
		MOVL    @XT,ACC
		MOVW    DP,#_dwPll_Cos_out
		IMPYL   P,XT,@_dwPll_Cos_out	    ;P = Cos_Out * Ref_Sin[31:0]
		QMPYL   ACC,XT,@_dwPll_Cos_out		;ACC = Cos_Out * Ref_Sin[63:32]
		LSL64   ACC:P,#13					;ACC->Q24, Phase error = 2 * ACC
		MOVW    DP,#_dwPhase_Err_Max
		MINL    ACC,@_dwPhase_Err_Max
		MOVW    DP,#_dwPhase_Err_Min
		MAXL    ACC,@_dwPhase_Err_Min
		MOVW    DP,#_dwPhase_Error_Out
		MOVL    @_dwPhase_Error_Out,ACC		;Q24
		
		;;For offset regulation
		MOVW    DP,#_dwPhase_Err_Offset
		ADDL    acc,@_dwPhase_Err_Offset
		MOVW    DP,#_dwPhase_Error_Out
		MOVL    @_dwPhase_Error_Out,ACC		;Q24
		
		;Notch filter
		;remove the 2nd freq harmony of the phase error
		CNTL_2P2Z 3
		
		;PLL controller
		CNTL_2P2Z 4
		
		;Update the frequency
		;Trace_Freq = PLLCon_Out + Ref_Freq
		MOVW    DP,#_wGridTieEnable
		MOV     AL,@_wGridTieEnable
		CMP     AL,#1
		B       Volt_Loop_End,LT
		MOVW    DP,#_dwInv_Frequency		
		MOVL    ACC,@_dwInv_Frequency		;Q24
		MOVW    DP,#_dwPllCon_Out
		ADDL    ACC,@_dwPllCon_Out
		MOVL    @XT,ACC
		MOVW    DP,#_dwPll_Trace_Freq_Ratio			
		IMPYL   P,XT,@_dwPll_Trace_Freq_Ratio			;Q20
		QMPYL   ACC,XT,@_dwPll_Trace_Freq_Ratio		
		LSL64   ACC:P,#8								;ACC -> Q20
		
		.if(INCR_BUILD = 1)		;disable the PLL
		NOP		
		.endif
		
		.if(INCR_BUILD = 2)		;disable the PLL
		NOP		
		.endif
		
		.if(INCR_BUILD = 3)		;enable the PLL
		MOVW    DP,#_dwPll_Trace_Freq
		MOVL    @_dwPll_Trace_Freq,ACC		
		.endif

Volt_Loop_End:		

VL_SKIP:

		MOVW    DP,#_dwPll_Sin_Out
		MOVL    ACC,@_dwPll_Sin_Out						;Q22
		MOV     T,#2
		LSL     ACC,T
		MOVW    DP,#_dwSine_Ref							;Q24
		MOVL    @_dwSine_Ref,ACC

		INV_ICMD  1

Curr_Loop_Begin:

Curr_Loop_1:
 .if (TRANSPHORM_TDPVXXXXE0C1)
		; Current loop can not complete if run at 100kHz
 .else
		SOLAR_CNTL_2P2Z 2
 .endif

Curr_Loop_End:

PWM_Duty_Cal_Begin:

		MOVW    DP,#_dwInv_Curr_LoopOut
		MOVL    ACC,@_dwInv_Curr_LoopOut
		MOVW    DP,#_dwInv_Voltage
		ADDL    ACC,@_dwInv_Voltage

		MOVW    DP,#_dwDuty_Cal_Max
		MINL    ACC,@_dwDuty_Cal_Max
		MOVW    DP,#_dwDuty_Cal_Min
		MAXL    ACC,@_dwDuty_Cal_Min
		
		;;For PLL test, open loop begin
		.if(INCR_BUILD = 1)
		MOVW    DP,#_dwPll_Sin_Out				;;Q22
		MOVL    ACC,@_dwPll_Sin_Out
		MOV     T,#8
		ASRL    ACC,T							;;Q14
		MOV     T,@AL
		MOVW    DP,#_wSinAmp
		MPY     P,T,@_wSinAmp
		MOV     ACC,@P	
		.endif
		;;For PLL test, open loop end
		
		MOVW    DP,#_dwDuty_Cal_Out
		MOVL    @_dwDuty_Cal_Out,ACC
		
		PWMDRV_FBINV 1,2

PWM_Duty_Cal_End:
		
		DLOG_4ch 1
		
		ZAPA

_DPL_COUNT_UP_END:	
	

;-----------------------------------------------------------------------------------------
; Interrupt management before exit

	.if(EPWMn_DPL_ISR=1)

	.if(EPWM1)
		MOVW 	DP,#_EPwm1Regs.ETCLR
		MOV 	@_EPwm1Regs.ETCLR,#0x01			; Clear EPWM1 Int flag
	.endif ; EPWM1

	.if(EPWM2)
		MOVW 	DP,#_EPwm2Regs.ETCLR
		MOV 	@_EPwm2Regs.ETCLR,#0x01			; Clear EPWM2 Int flag
	.endif ; EPWM2

	.if(EPWM3)
		MOVW 	DP,#_EPwm3Regs.ETCLR
		MOV 	@_EPwm3Regs.ETCLR,#0x01			; Clear EPWM3 Int flag
	.endif ; EPWM3

	.if(EPWM4)
		MOVW 	DP,#_EPwm4Regs.ETCLR
		MOV 	@_EPwm4Regs.ETCLR,#0x01			; Clear EPWM4 Int flag
	.endif ; EPWM4

	.if(EPWM5)
		MOVW 	DP,#_EPwm5Regs.ETCLR
		MOV 	@_EPwm5Regs.ETCLR,#0x01			; Clear EPWM5 Int flag
	.endif ; EPWM5

	.if(EPWM6)
		MOVW 	DP,#_EPwm6Regs.ETCLR
		MOV 	@_EPwm6Regs.ETCLR,#0x01			; Clear EPWM6 Int flag
	.endif ; EPWM6

		MOVW 	DP,#_PieCtrlRegs.PIEACK			; Acknowledge PIE interrupt Group 3
		MOV 	@_PieCtrlRegs.PIEACK, #0x4
	.endif ; EPWMn_ISR


	.if(ADC_DPL_ISR=1)
	; Case where ISR is triggered by ADC 
		MOVW    DP,#_AdcRegs.ADCINTFLGCLR
		MOV     @_AdcRegs.ADCINTFLGCLR,#0x1

		MOVW 	DP,#_PieCtrlRegs.PIEACK			; Acknowledge PIE interrupt Group 1
		MOV 	@_PieCtrlRegs.PIEACK,#0x1
	.endif ; ADC_ISR 

	
;-----------------------------------------------------------------------------------------
; full context restore
;		SETC	INTM							; set INTM to protect context restore
		POP   	XT
		POP   	XAR7
		POP   	XAR6
		POP   	XAR5
		POP   	XAR4
		POP   	XAR3
		POP   	XAR2
		POP   	AR1H:AR0H
		IRET									; return from interrupt
		.end

; end of file
