//-------------------------------------------------------------------------------------
//	FILE:			PWM_PFC2PhIL_Cnf.c
//
//	Description:	Driver Config to support a 2 phase Interleaved PFC
//					with Duty balance Adjustment but Non HiRes
//
//	Version: 		2.0
//  Target:  		TMS320F2802x, TMS320F2803x 
//
// The function call is:
//
// 		PWM_PFC2PhiL_CNF(int16 n, int16 period)
//
// Function arguments defined as:
//-------------------------------
// n = 		Target ePWM module, 1,2,...16.  e.g. if n=2, then target is ePWM2
// period = PWM period in Sysclks
//
//-------------------------------------------------------------------------------------
#include "PeripheralHeaderIncludes.h"
#include "DSP2803x_EPWM_defines.h" 		// useful defines specific to EPWM 

#include "SolarHv_DCAC-Settings.h"

extern volatile struct EPWM_REGS *ePWM[];


void PWM_SolarInv_CNF(int16 n, int16 Period)
{
	//Time Base SubModule Register
	(*ePWM[n]).TBCTL.bit.PRDLD = TB_IMMEDIATE;	// set Immediate load
	(*ePWM[n]).TBPRD= (Period>>1);
	(*ePWM[n]).TBPHS.half.TBPHS =0;
	(*ePWM[n]).TBCTR = 0;
	(*ePWM[n]).TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN;
	(*ePWM[n]).TBCTL.bit.HSPCLKDIV = TB_DIV1;
	(*ePWM[n]).TBCTL.bit.CLKDIV = TB_DIV1;
	(*ePWM[n]).TBCTL.bit.PHSEN = TB_DISABLE;
	(*ePWM[n]).TBCTL.bit.SYNCOSEL = TB_CTR_ZERO; // sync "down-stream" 
	
	// Counter compare submodule registers
	(*ePWM[n]).CMPCTL.bit.LOADAMODE = CC_CTR_PRD;
	(*ePWM[n]).CMPCTL.bit.LOADBMODE = CC_CTR_PRD;
	(*ePWM[n]).CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	(*ePWM[n]).CMPCTL.bit.SHDWBMODE = CC_SHADOW;

	// Action Qualifier SubModule Registers
	(*ePWM[n]).AQCTLA.bit.CAU = AQ_CLEAR;
	(*ePWM[n]).AQCTLA.bit.CAD = AQ_SET;
	//(*ePWM[n]).AQCTLB.bit.CBU = AQ_SET;
	//(*ePWM[n]).AQCTLB.bit.CBD = AQ_CLEAR;
	
	// Deadband SubModule Registers
	(*ePWM[n]).DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; //Both rising and falling edge
	(*ePWM[n]).DBCTL.bit.POLSEL = DB_ACTV_HIC;	// Active high complementary

#if TRANSPHORM_TDPVXXXXE0C1
	//
	// Don't enable trip zone until current sensors are properly scaled in the hardware

	(*ePWM[n]).DBFED = 5;						// Deadtime is ~83ns @ 60MHz
	(*ePWM[n]).DBRED = 5;
#else
	(*ePWM[n]).DBFED = 90;						// Deadtime is 2us (? assuming 45MHz)
	(*ePWM[n]).DBRED = 90;		
	
	// Configure the Tripzone Registers
	EALLOW;	
//===========================================================================
// TZA events can force EPWMxA
// TZB events can force EPWMxB
	(*ePWM[n]).TZCTL.bit.TZA = TZ_FORCE_LO; // EPWM1A will go low 
	(*ePWM[n]).TZCTL.bit.TZB = TZ_FORCE_LO; // EPWM1B will go low 
	(*ePWM[n]).TZFRC.bit.OST = 1;			// Turn off the PWM

	EDIS;
#endif
	(*ePWM[n]).CMPA.half.CMPA = 0;		   //Initialize the CMP register
}


