#ifndef _PROJSETTINGS_H
#define _PROJSETTINGS_H

//**********************************************************************************
//  NOTE: WHEN CHANGING THIS FILE PLEASE REBUILD ALL
//**********************************************************************************

// All new protecion features defines here

#define UNDER_VOLTAGE_ENABLE     0              // set to 1 to enable the under voltage lock out feature
#define UNDER_VOLTAGE_TRIP      10              // set the minimum voltage to begin operation
#define HYSTERESIS_SET           5              // set the amount of hysteresis for the under voltage function
#define OVER_VOLTAGE_TRIP       420             // set the over voltage limit here

#define COMPARATOR_MAX          22             //20 default // set the DAC value for the high side trip in amps
#define COMPARATOR_MIN          22             //20 default // set the DAC value for the low side trip in amps

#define VOLTAGE_SCALING        4.23             // scaling value for volts
#define CURRENT_SCALING_DAC    22.7             // scaling value for amps

#define DELAY_COUNTER      500          // Delay count before current trip to allow start up

#define PolarityBit     (GpioDataRegs.GPADAT.bit.GPIO27)        // use gpio29 for de-bug

#define Uint8 unsigned char

#define TRANSPHORM_TDPVXXXXE0C1	1
#if TRANSPHORM_TDPVXXXXE0C1

/* Uncomment only one of the following lines */

//#define TRANSPHORM_SWITCHING_FREQUENCY_50KHZ   1   //  50kHz switching frequency
#define TRANSPHORM_SWITCHING_FREQUENCY_100KHZ	1	// 100kHz switching frequency
//#define TRANSPHORM_SWITCHING_FREQUENCY_200KHZ	1	// 200kHz switching frequency

/* Parameters specific to switching frequency */
#if TRANSPHORM_SWITCHING_FREQUENCY_50KHZ
#define TRANSPHORM_PWM_PRD                  1200
#define TRANSPHORM_LOOP_DECIMATION_COUNT    2.5      // Perform ADC conversions and run control loop every 50/2.5 = 20kHz
#define TRANSPHORM_SAMPLE_TIME              (0.00002 * TRANSPHORM_LOOP_DECIMATION_COUNT)        // 20e-6 * 2.5
#define TRANSPHORM_SIN_AMP                  0.156 //0.0982 for 270vin-120vout //0.156 normal
#elif TRANSPHORM_SWITCHING_FREQUENCY_100KHZ
#define TRANSPHORM_PWM_PRD					600
#define TRANSPHORM_LOOP_DECIMATION_COUNT	5		// Perform ADC conversions and run control loop every 100/5 = 20kHz
#define TRANSPHORM_SAMPLE_TIME				(0.00001 * TRANSPHORM_LOOP_DECIMATION_COUNT)		// 10e-6 * 5
#define TRANSPHORM_SIN_AMP					0.078
#elif TRANSPHORM_SWITCHING_FREQUENCY_200KHZ
#define TRANSPHORM_PWM_PRD					300
#define TRANSPHORM_LOOP_DECIMATION_COUNT	10		// Perform ADC conversions and run control loop every 200/10 = 20kHz
#define TRANSPHORM_SAMPLE_TIME				(0.000005 * TRANSPHORM_LOOP_DECIMATION_COUNT)		// 5e-6 * 10
#define TRANSPHORM_SIN_AMP					0.039
#endif

#define TRANSPHORM_LOOP_PRD	(TRANSPHORM_PWM_PRD * TRANSPHORM_LOOP_DECIMATION_COUNT)		// Decimate the control loop

//==================================================================================
// Incremental Build options for System check-out
//==================================================================================
// BUILD 1 	Open loop DC->AC (only option currently supported)

#define INCR_BUILD 1
#define VoltCurrLoopExecRatio	8
#define Protect_Enable	0
#define	Protect_Utiligy_Enable  0

#else

//==================================================================================
// Incremental Build options for System check-out
//==================================================================================
// BUILD 1 	Open loop boost check + ADC feedback
// BUILD 2 	Complete PFC Build
 
#define INCR_BUILD 3
#define VoltCurrLoopExecRatio	8
#define Protect_Enable	1
#define	Protect_Utiligy_Enable  1
#endif
		

//==================================================================================
// Interrupt Framework options
//==================================================================================

#define EPWMn_DPL_ISR	0	// for EPWM triggered ISR set as 1
#define ADC_DPL_ISR	    1	// for ADC triggered ISR set as 1 

//----------------------------------------------------------------------------------
// If EPWMn_DPL__ISR = 1, then choose which module
//----------------------------------------------------------------------------------
#define EPWM1			1	// EPWM1 provides ISR trigger
#define EPWM2			0 	// EPWM2 provides ISR trigger
#define EPWM3			0	// EPWM3 provides ISR trigger
#define EPWM4			0	// EPWM4 provides ISR trigger
#define EPWM5			0	// EPWM5 provides ISR trigger
#define EPWM6			0	// EPWM6 provides ISR trigger

//==================================================================================
// System Settings
//----------------------------------------------------------------------------------
#define HistorySize 8


#endif //_PROJSETTINGS_H

