/*
 * TripZone.c
 *
 *  Created on: Feb 22, 2016
 *      Author: rpregitzer
 */

#include "DSP28x_Project.h"     // DSP28x Headerfile
#include "DSP2803x_EPWM_defines.h" 		// useful defines specific to EPWM
#include "SolarHv_DCAC-Settings.h"


void TripZoneInit()
{
	EALLOW;

	// initialize comparator 2
	Comp2Regs.COMPCTL.bit.COMPDACEN  = 0x1;							// Enable comparator block two
	Comp2Regs.COMPCTL.bit.SYNCSEL    = 0x0;							// asynchronous version of the COMP signal is passed to the EPWM/GPIO module
	Comp2Regs.COMPCTL.bit.COMPSOURCE = 0x0;							// inverting input of the comparator is connected to the internal DAC

	AdcRegs.COMPHYSTCTL.bit.COMP2_HYST_DISABLE = 1;	            	// hysteresis disabled for comparator 2

	// map comparator 2
	EPwm1Regs.DCTRIPSEL.bit.DCAHCOMPSEL = DC_COMP2OUT; 			// EPWM1 use comparator 2 for DCAH
	EPwm2Regs.DCTRIPSEL.bit.DCAHCOMPSEL = DC_COMP2OUT; 			// EPWM2 use comparator 2 for DCAH

	// set up the event qualifications for DCAH
	EPwm1Regs.TZDCSEL.bit.DCAEVT1 = TZ_DCAH_HI;		 //  	DCAH hi = DCAEVT1 high for EPWM1
	EPwm2Regs.TZDCSEL.bit.DCAEVT1 = TZ_DCAH_HI;		 //		DCAH hi = DCAEVT1 high for EPWM2

	// set up the filtering options for each DCAEVT1
	EPwm1Regs.DCACTL.bit.EVT1SRCSEL = DC_EVT1;		 // select DCAEVT1 without filtering for EPWM1
	EPwm2Regs.DCACTL.bit.EVT1SRCSEL = DC_EVT1;		 // select DCAEVT1 without filtering for EPWM2

	// select sync or async  for each DCAEVT1
	EPwm1Regs.DCACTL.bit.EVT1FRCSYNCSEL = DC_EVT_ASYNC;		// select async for DCAEVT1 for EPWM1
	EPwm2Regs.DCACTL.bit.EVT1FRCSYNCSEL = DC_EVT_ASYNC;		// select async for DCAEVT1 for EPWM1

	// The TZA and TZB trip zone events are defined below.  DCAEVT1 and DCBEVT1 are defined as one shot triggers.
	EPwm1Regs.TZCTL.bit.TZA = TZ_FORCE_LO; // 0x2 EPWMxA will go low
	EPwm1Regs.TZCTL.bit.TZB = TZ_FORCE_LO; // 0x2 EPWMxA will go low
	EPwm2Regs.TZCTL.bit.TZA = TZ_FORCE_LO; // 0x2 EPWMxB will go low
	EPwm2Regs.TZCTL.bit.TZB = TZ_FORCE_LO; // 0x2 EPWMxB will go low

    // With one shot enabled a trip will stay off until the event is cleared.  (power cycle is required for this board)
	// disable these next two statement for cycle by cycle pwm off (useful for debug)
    EPwm1Regs.TZSEL.bit.DCAEVT1 = 0x1;      // One shot enable of trip zone for epwm1
    EPwm2Regs.TZSEL.bit.DCAEVT1 = 0x1;      // One shot enable of trip zone for epwm2

	EPwm1Regs.TZSEL.bit.OSHT6 = 1;      	// Emulator halt is a trigger source when this bit is enabled
	EPwm2Regs.TZSEL.bit.OSHT6 = 1;		 	// Emulator halt is a trigger source when this bit is enabled

	//clear any spurious trips
	EPwm1Regs.TZCLR.bit.DCAEVT1=1;          //

	EDIS;
}
